# $Id: Document.pm 42299 2014-09-26 14:30:54Z wsl $
# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Static/Document.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::Static::Document;

use Xyzzy::Static;

use Aselect::UI::Document -self;
use Xyzzy::Static::Document -mixin;

use constant rootname => 'document';
